controller

package
v0.0.0-...-cd99360 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2025 License: MIT Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrContainerExit = errors.New("container exited")
)

Functions

This section is empty.

Types

type EnvironmentBuildReconciler

type EnvironmentBuildReconciler struct {
	client.Client
	Scheme *runtime.Scheme
}

EnvironmentBuildReconciler reconciles a EnvironmentBuild object

func (*EnvironmentBuildReconciler) Reconcile

Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.

For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.19.1/pkg/reconcile

func (*EnvironmentBuildReconciler) SetupWithManager

func (r *EnvironmentBuildReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager sets up the controller with the Manager.

type TaskReconciler

type TaskReconciler struct {
	client.Client
	Scheme   *runtime.Scheme
	Recorder record.EventRecorder
}

TaskReconciler reconciles a Task object

func NewTaskReconciler

func NewTaskReconciler(mgr ctrl.Manager) *TaskReconciler

func (*TaskReconciler) Reconcile

func (r *TaskReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)

Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.

func (*TaskReconciler) SetupWithManager

func (r *TaskReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager sets up the controller with the Manager.

Jump to